@@ -102,6 +102,11 @@ UpdateControllerMender::UpdateControllerMender(QObject *parent):
     qCDebug(dcPlatformUpdate()) << "Initialized mender update controller. Current state" << m_state;
 }
 
+PlatformUpdateController::UpdateType UpdateControllerMender::updateType() const
+{
+    return PlatformUpdateController::UpdateTypeSystem;
+}
+
 bool UpdateControllerMender::updateManagementAvailable() const
 {
     // FIXME: ask systemd if mender is running
